## dbt-snowflake 1.10.3 - November 06, 2025

### Features

- Add platform_detection_timeout_seconds configuration param to disable eager metadata detection in the snowflake-connector ([#1278](https://github.com/dbt-labs/dbt-adapters/issues/1278))

### Under the Hood

- Improve snowflake connector log handling ([#1399](https://github.com/dbt-labs/dbt-adapters/issues/1399))
- Update bigquery job handling to invoke job.cancel on timeout ([#1355](https://github.com/dbt-labs/dbt-adapters/issues/1355))

### Dependencies

- Drop support for python 3.9 ([#1412](https://github.com/dbt-labs/dbt-adapters/pull/1412))
